extern int nextwork(unsigned char **);
extern unsigned char *nextchar(unsigned char *c);
extern void readstructs();
extern void readedict();

